Authors and Contributors
========================

- David Eyk (`eykd`_)—Author and Maintainer
- Ryan Rubin (`ryanmrubin`_)

.. _eykd: https://github.com/eykd/
.. _ryanmrubin: https://github.com/ryanmrubin/
